@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[2]:
+# In[6]:
 
 
 
@@ -89,7 +89,8 @@ def start_server(debug = False):
                     if debug == True:
                         print("ERROR OR CLIENT DONE")
                         print(g)
-                        resultsize = str(len(pickle.dumps(g,-1)))
+                        result = g
+                        resultsize = str(len(pickle.dumps(result,-1)))
 
                         conn.send(pickle.dumps(resultsize))
 
